pub fn search_prefix(
prefix: &str,
) -> impl Iterator<Item = &'static FunctionInfo>Expand description
Return all functions whose name starts with the given prefix (case-insensitive).
pub fn search_prefix(
prefix: &str,
) -> impl Iterator<Item = &'static FunctionInfo>Return all functions whose name starts with the given prefix (case-insensitive).