macro_rules! info_nonl {
($($arg:tt)*) => { ... };
}Expand description
Print an informational message to stderr without a trailing newline. Silenced by --quiet.
macro_rules! info_nonl {
($($arg:tt)*) => { ... };
}Print an informational message to stderr without a trailing newline. Silenced by --quiet.